@@ -2,6 +2,8 @@
 import re
 import htmlentitydefs
 import time
+from os.path import isfile, getsize
+
 url_re = re.compile(
     r'^https?://' # http:// or https://
     r'(?:(?:[A-Z0-9]+(?:-*[A-Z0-9]+)*\.)+[A-Z]{2,6}|' #domain...
@@ -180,11 +182,11 @@ def kasabi_store(dataset, filename):
   """Load a file of ntriples into a Kasabi dataset. Expects a pytassium Dataset instance as a parameter. Will print to console"""
   print "Uploading '%s'" % filename
   
-  if not os.path.isfile(filename):
+  if not isfile(filename):
     print "%s is not a valid filename" % filename
     return
 
-  if os.path.getsize(filename) < 2000000:
+  if getsize(filename) < 2000000:
     response, data = dataset.store_file(filename)
     if not response.status in range(200, 300):
       print "Request failed: %d %s - %s" % (response.status, response.reason, data)
